describe('Servicios módulo crear cobranza', function() {

    beforeEach(function() {

        module('focaCrearCobranza');

        inject(module(function($provide) {
            $provide.value('API_ENDPOINT', {
                URL: 'localhost'
            });
        }));
    });

    describe('servicio focaCrearCobranzaService', function() {

        var servicio;
        var httpBackend;

        beforeEach(function() {
            inject(function($httpBackend, _focaCrearCobranzaService_) {
                httpBackend = $httpBackend;
                servicio = _focaCrearCobranzaService_;
            });
        });

        it('existe el servicio focaCrearCobranzaService', function() {

            //assert
            expect(typeof servicio).toEqual('object');
        });

        it('getNumeroRecibo llama a ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;

            httpBackend.expectGET('localhost/recibo/numero-siguiente').respond(responseFake);

            //act
            servicio.getNumeroRecibo().then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('getCotizacionByIdMoneda llama a ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;
            var paramFake = 1;

            httpBackend.expectGET('localhost/moneda/' + paramFake).respond(responseFake);

            //act
            servicio.getCotizacionByIdMoneda(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('guardarCobranza llama a ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;
            var paramFake = 1;

            httpBackend.expectPOST('localhost/recibo/guardar', paramFake).respond(responseFake);

            //act
            servicio.guardarCobranza(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('getCobradorById llama a ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;
            var paramFake = 1;

            httpBackend.expectGET('localhost/vendedor-cobrador/' + paramFake).respond(responseFake);

            //act
            servicio.getCobradorById(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('enviarComprobantePorMail llama a ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;
            var paramFake = 1;

            httpBackend.expectPOST('localhost/mail/comprobante',
                {receiver: paramFake}).respond(responseFake);

            //act
            servicio.enviarComprobantePorMail(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('actualizarEmail llama a ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;
            var paramFake = 1;

            httpBackend.expectPOST('localhost/cliente/update/email',
                {mail: paramFake}).respond(responseFake);

            //act
            servicio.actualizarEmail(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });
    });

});